module Config.MapViewConfig exposing (..)

import Http
import GeoJson
import MapLoader exposing (Country)
import Zoom exposing (Zoom)
import Data.DataLoader exposing (Entry)
import Scale exposing (ContinuousScale)

type Progress
    = Loading
    | Success
    | Failure String

type alias MapFrame =
    { xScale: ContinuousScale Float
    , yScale: ContinuousScale Float
    }

type CountryType
    = Unknown
    | SchengenState
    | ConsulateCountry

type alias MapCountry = 
    { context: Country
    , variant: CountryType
    , entries: List Entry
    }

type alias Model =
    { progress: Progress
    , countries: List MapCountry
    , hoveredCountry: Maybe Country
    , selectedYear: Maybe Int
    , selectedConsulate: Maybe ( MapCountry, Maybe String )
    , zoom: Zoom
    }

type alias ChernoffConfig =
    { x: Float
    , y: Float
    , mouth:
        { angle: Float
        , length: Float
        }
    , nose: Float
    , eyes:
        { left: Float
        , right: Float
        }
    }

type Msg
    = NoOp
    | MapDataReceived (Result Http.Error GeoJson.GeoJson)
    | YearChange (Maybe Int)
    | ConsulateChange (Maybe String)
    | HoverCountry (Maybe Country)
    | ClickCountry MapCountry
    | MapZoom Zoom.OnZoom
    